@@ -127,7 +127,7 @@ static int insert_into_buffer(
 }
 
 /*
- * format set is the only global specific option that
+ * format set is global specific option that
  * doesn't apply at system/subsystem level.
  */
 static int corosync_main_config_format_set (
@@ -228,6 +228,40 @@ parse_error:
 	return (-1);
 }
 
+/*
+ * blackbox is another global specific option that
+ * doesn't apply at system/subsystem level.
+ */
+static int corosync_main_config_blackbox_set (
+	const char **error_string)
+{
+	const char *error_reason;
+	char *value = NULL;
+
+	if (map_get_string("logging.blackbox", &value) == CS_OK) {
+		if (strcmp (value, "on") == 0) {
+			(void)logsys_blackbox_set(QB_TRUE);
+		} else if (strcmp (value, "off") == 0) {
+			(void)logsys_blackbox_set(QB_FALSE);
+		} else {
+			error_reason = "unknown value for blackbox";
+			free(value);
+			goto parse_error;
+		}
+
+		free(value);
+	} else {
+		(void)logsys_blackbox_set(QB_TRUE);
+	}
+
+	return (0);
+
+parse_error:
+	*error_string = error_reason;
+
+	return (-1);
+}
+
 static int corosync_main_config_log_destination_set (
 	const char *path,
 	const char *key,
@@ -489,7 +523,6 @@ static int corosync_main_config_set (
 	else {
 		if (logsys_config_debug_set (subsys, LOGSYS_DEBUG_OFF) < 0) {
 			error_reason = "unable to set debug off";
-			free(value);
 			goto parse_error;
 		}
 	}
@@ -522,6 +555,10 @@ static int corosync_main_config_read_logging (
 		goto parse_error;
 	}
 
+	if (corosync_main_config_blackbox_set(&error_reason) < 0) {
+		goto parse_error;
+	}
+
 	if (corosync_main_config_set ("logging", NULL, &error_reason) < 0) {
 		goto parse_error;
 	}
