@@ -119,6 +119,8 @@ static char *format_buffer=NULL;
 
 static int logsys_thread_started = 0;
 
+static int logsys_blackbox_enabled = 1;
+
 static int _logsys_config_subsys_get_unlocked (const char *subsys)
 {
 	unsigned int i;
@@ -166,15 +168,37 @@ static int logsys_config_file_set_unlocked (
 		return (0);
 	}
 
+	if (logsys_loggers[subsysid].target_id > 0 &&
+	    logsys_loggers[subsysid].logfile != NULL &&
+	    strcmp(file, logsys_loggers[subsysid].logfile) == 0) {
+		return (0);
+	}
+
 	if (strlen(file) >= PATH_MAX) {
 		snprintf (error_string_response,
 			sizeof(error_string_response),
-			"%s: logfile name exceed maximum system filename lenght",
+			"%s: logfile name exceed maximum system filename length",
 			logsys_loggers[subsysid].subsys);
 		*error_string = error_string_response;
 		return (-1);
 	}
 
+	if (logsys_loggers[subsysid].logfile != NULL) {
+		free(logsys_loggers[subsysid].logfile);
+		logsys_loggers[subsysid].logfile = NULL;
+	}
+
+	logsys_loggers[subsysid].logfile = strdup(file);
+
+	if (logsys_loggers[subsysid].logfile == NULL) {
+		snprintf (error_string_response,
+			sizeof(error_string_response),
+			"Unable to allocate memory for logfile '%s'",
+			file);
+		*error_string = error_string_response;
+		return (-1);
+	}
+
 	for (i = 0; i <= LOGSYS_MAX_SUBSYS_COUNT; i++) {
 		if ((logsys_loggers[i].logfile != NULL) &&
 		    (strcmp (logsys_loggers[i].logfile, file) == 0) &&
@@ -186,15 +210,6 @@ static int logsys_config_file_set_unlocked (
 			return (0);
 		}
 	}
-	logsys_loggers[subsysid].logfile = strdup(file);
-	if (logsys_loggers[subsysid].logfile == NULL) {
-		snprintf (error_string_response,
-			sizeof(error_string_response),
-			"Unable to allocate memory for logfile '%s'",
-			file);
-		*error_string = error_string_response;
-		return (-1);
-	}
 
 	if (logsys_loggers[subsysid].target_id > 0) {
 		int num_using_current = 0;
@@ -320,6 +335,12 @@ int _logsys_system_setup(
 	 * _logsys_subsys_filename_add (i, "util.c");
 	 */
 
+	/*
+	 * This file (logsys.c) is not exactly QB. We need tag for logsys.c if flightrecorder init
+	 * fails, and QB seems to be closest.
+	 */
+	_logsys_subsys_filename_add (i, "logsys.c");
+
 	i = LOGSYS_MAX_SUBSYS_COUNT;
 
 	pthread_mutex_lock (&logsys_config_mutex);
@@ -351,9 +372,16 @@ int _logsys_system_setup(
 			  QB_LOG_FILTER_FILE, "*", LOG_TRACE);
 	qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_SIZE, IPC_LOGSYS_SIZE);
 	qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_THREADED, QB_FALSE);
-	qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_ENABLED, QB_TRUE);
+
+	/*
+	 * Blackbox is disabled at the init and enabled later based
+	 * on config (logging.blackbox) value.
+	 */
+	qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_ENABLED, QB_FALSE);
 
 	if (logsys_format_set(NULL) == -1) {
+		pthread_mutex_unlock (&logsys_config_mutex);
+
 		return -1;
 	}
 
@@ -739,10 +767,26 @@ static void _logsys_config_apply_per_subsys(int32_t s)
 	logsys_loggers[s].dirty = QB_FALSE;
 }
 
+static void _logsys_config_apply_blackbox(void) {
+	int blackbox_enable_res;
+
+	blackbox_enable_res = qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_ENABLED, logsys_blackbox_enabled);
+
+	if (blackbox_enable_res < 0) {
+		LOGSYS_PERROR (-blackbox_enable_res, LOGSYS_LEVEL_WARNING,
+		    "Unable to initialize log flight recorder. "\
+		    "The most common cause of this error is " \
+		    "not enough space on /dev/shm. Corosync will continue work, " \
+		    "but blackbox will not be available");
+	}
+}
+
 void logsys_config_apply(void)
 {
 	int32_t s;
 
+	_logsys_config_apply_blackbox();
+
 	for (s = 0; s <= LOGSYS_MAX_SUBSYS_COUNT; s++) {
 		if (strcmp(logsys_loggers[s].subsys, "") == 0) {
 			continue;
@@ -810,3 +854,29 @@ int logsys_thread_start (void)
 
 	return (0);
 }
+
+void logsys_blackbox_set(int enable)
+{
+
+	pthread_mutex_lock (&logsys_config_mutex);
+
+	logsys_blackbox_enabled = enable;
+
+	pthread_mutex_unlock (&logsys_config_mutex);
+}
+
+/*
+ * To set correct pid to qb blackbox filename after tty dettach (fork) we have to
+ * close (this function) and (if needed) reopen blackbox (logsys_blackbox_postfork function).
+ */
+void logsys_blackbox_prefork(void)
+{
+
+	(void)qb_log_ctl(QB_LOG_BLACKBOX, QB_LOG_CONF_ENABLED, QB_FALSE);
+}
+
+void logsys_blackbox_postfork(void)
+{
+
+	_logsys_config_apply_blackbox();
+}
