@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2015 Red Hat, Inc.
+ * Copyright (c) 2009-2020 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -80,6 +80,7 @@ static uint8_t two_node = 0;
 
 static uint8_t wait_for_all = 0;
 static uint8_t wait_for_all_status = 0;
+static uint8_t wait_for_all_autoset = 0; /* Wait for all is not set explicitly and follows two_node */
 
 static enum {ATB_NONE, ATB_LOWEST, ATB_HIGHEST, ATB_LIST} auto_tie_breaker = ATB_NONE, initial_auto_tie_breaker = ATB_NONE;
 static int lowest_node_id = -1;
@@ -1015,7 +1016,7 @@ static void are_we_quorate(unsigned int total_votes)
 				   "Waiting for all cluster members. "
 				   "Current votes: %d expected_votes: %d",
 				   total_votes, us->expected_votes);
-			cluster_is_quorate = 0;
+			assert(!cluster_is_quorate);
 			return;
 		}
 		update_wait_for_all_status(0);
@@ -1272,10 +1273,10 @@ static char *votequorum_readconfig(int runtime)
 	/*
 	 * gather basic data here
 	 */
-	icmap_get_uint32("quorum.expected_votes", &expected_votes);
+	(void)icmap_get_uint32("quorum.expected_votes", &expected_votes);
 	have_nodelist = votequorum_read_nodelist_configuration(&node_votes, &node_count, &node_expected_votes);
 	have_qdevice = votequorum_qdevice_is_configured(&qdevice_votes);
-	icmap_get_uint8("quorum.two_node", &two_node);
+	(void)icmap_get_uint8("quorum.two_node", &two_node);
 
 	/*
 	 * do config verification and enablement
@@ -1316,17 +1317,15 @@ static char *votequorum_readconfig(int runtime)
 	 * Enable special features
 	 */
 	if (!runtime) {
-		if (two_node) {
-			wait_for_all = 1;
+		(void)icmap_get_uint8("quorum.allow_downscale", &allow_downscale);
+		if (icmap_get_uint8("quorum.wait_for_all", &wait_for_all) != CS_OK) {
+			wait_for_all_autoset = 1;
 		}
-
-		icmap_get_uint8("quorum.allow_downscale", &allow_downscale);
-		icmap_get_uint8("quorum.wait_for_all", &wait_for_all);
-		icmap_get_uint8("quorum.last_man_standing", &last_man_standing);
-		icmap_get_uint32("quorum.last_man_standing_window", &last_man_standing_window);
-		icmap_get_uint8("quorum.expected_votes_tracking", &ev_tracking);
-		icmap_get_uint8("quorum.auto_tie_breaker", &atb);
-		icmap_get_string("quorum.auto_tie_breaker_node", &atb_string);
+		(void)icmap_get_uint8("quorum.last_man_standing", &last_man_standing);
+		(void)icmap_get_uint32("quorum.last_man_standing_window", &last_man_standing_window);
+		(void)icmap_get_uint8("quorum.expected_votes_tracking", &ev_tracking);
+		(void)icmap_get_uint8("quorum.auto_tie_breaker", &atb);
+		(void)icmap_get_string("quorum.auto_tie_breaker_node", &atb_string);
 
 		/* auto_tie_breaker defaults to LOWEST */
 		if (atb) {
@@ -1362,6 +1361,15 @@ static char *votequorum_readconfig(int runtime)
 
 	}
 
+	/*
+	 * Changing of wait_for_all during runtime is not supported, but changing of two_node is
+	 * and two_node may set wfa if not configured explicitly. It is safe to unset it
+	 * (or set it back) when two_node changes.
+	 */
+	if (wait_for_all_autoset) {
+		wait_for_all = two_node;
+	}
+
 	/* two_node and auto_tie_breaker are not compatible as two_node uses
 	 * a fence race to decide quorum whereas ATB decides based on node id
 	 */
@@ -1518,7 +1526,7 @@ static char *votequorum_readconfig(int runtime)
 		us->expected_votes = node_expected_votes;
 	} else {
 		us->votes = 1;
-		icmap_get_uint32("quorum.votes", &us->votes);
+		(void)icmap_get_uint32("quorum.votes", &us->votes);
 	}
 
 	if (expected_votes) {
@@ -1540,7 +1548,15 @@ static char *votequorum_readconfig(int runtime)
 	update_ev_barrier(us->expected_votes);
 	update_two_node();
 	if (wait_for_all) {
-		update_wait_for_all_status(1);
+		if (!runtime) {
+			update_wait_for_all_status(1);
+		}
+	} else if (wait_for_all_autoset && wait_for_all_status) {
+		/*
+		 * Reset wait for all status for consistency when wfa is auto-unset by 2node.
+		 * wait_for_all_status would be ignored by are_we_quorate anyway.
+		 */
+		update_wait_for_all_status(0);
 	}
 
 out:
@@ -1569,7 +1585,7 @@ static void votequorum_refresh_config(
 		return ;
 	}
 
-	icmap_get_uint8("quorum.cancel_wait_for_all", &cancel_wfa);
+	(void)icmap_get_uint8("quorum.cancel_wait_for_all", &cancel_wfa);
 	if (strcmp(key_name, "quorum.cancel_wait_for_all") == 0 &&
 	    cancel_wfa >= 1) {
 	        icmap_set_uint8("quorum.cancel_wait_for_all", 0);
@@ -1707,7 +1723,11 @@ static int votequorum_exec_send_qdevice_reconfigure(const char *oldname, const c
 
 	req_exec_quorum_qdevice_reconfigure.header.id = SERVICE_ID_MAKE(VOTEQUORUM_SERVICE, MESSAGE_REQ_EXEC_VOTEQUORUM_QDEVICE_RECONFIGURE);
 	req_exec_quorum_qdevice_reconfigure.header.size = sizeof(req_exec_quorum_qdevice_reconfigure);
+
+	assert(strlen(oldname) < sizeof(req_exec_quorum_qdevice_reconfigure.oldname));
 	strcpy(req_exec_quorum_qdevice_reconfigure.oldname, oldname);
+
+	assert(strlen(newname) < sizeof(req_exec_quorum_qdevice_reconfigure.newname));
 	strcpy(req_exec_quorum_qdevice_reconfigure.newname, newname);
 
 	iov[0].iov_base = (void *)&req_exec_quorum_qdevice_reconfigure;
@@ -1730,6 +1750,8 @@ static int votequorum_exec_send_qdevice_reg(uint32_t operation, const char *qdev
 	req_exec_quorum_qdevice_reg.header.id = SERVICE_ID_MAKE(VOTEQUORUM_SERVICE, MESSAGE_REQ_EXEC_VOTEQUORUM_QDEVICE_REG);
 	req_exec_quorum_qdevice_reg.header.size = sizeof(req_exec_quorum_qdevice_reg);
 	req_exec_quorum_qdevice_reg.operation = operation;
+
+	assert(strlen(qdevice_name_req) < sizeof(req_exec_quorum_qdevice_reg.qdevice_name));
 	strcpy(req_exec_quorum_qdevice_reg.qdevice_name, qdevice_name_req);
 
 	iov[0].iov_base = (void *)&req_exec_quorum_qdevice_reg;
@@ -2663,8 +2685,12 @@ static void message_handler_req_lib_votequorum_setexpected (void *conn, const vo
 	 */
 	newquorum = calculate_quorum(1, req_lib_votequorum_setexpected->expected_votes, &total_votes);
 	allow_downscale = allow_downscale_status;
-	if (newquorum < total_votes / 2 ||
-	    newquorum > total_votes) {
+	/*
+	 * Setting expected_votes < total_votes doesn't make sense.
+	 * For quorate cluster prevent cluster to become unquorate.
+	 */
+	if (req_lib_votequorum_setexpected->expected_votes < total_votes ||
+	    (cluster_is_quorate && (newquorum > total_votes))) {
 		error = CS_ERR_INVALID_PARAM;
 		goto error_exit;
 	}
