@@ -191,6 +191,10 @@ struct totem_config {
 
 	int ip_version;
 
+	unsigned int block_unlisted_ips;
+
+	unsigned int cancel_token_hold_on_retransmit;
+
 	void (*totem_memb_ring_id_create_or_load) (
 	    struct memb_ring_id *memb_ring_id,
 	    const struct totem_ip_address *addr);
