@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2017 Red Hat, Inc.
+ * Copyright (c) 2015-2019 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -36,8 +36,9 @@
 
 #include <string.h>
 
+#include "log.h"
+#include "log-common.h"
 #include "qnetd-algo-ffsplit.h"
-#include "qnetd-log.h"
 #include "qnetd-log-debug.h"
 #include "qnetd-cluster-list.h"
 #include "qnetd-cluster.h"
@@ -52,7 +53,7 @@ enum qnetd_algo_ffsplit_cluster_state {
 
 struct qnetd_algo_ffsplit_cluster_data {
 	enum qnetd_algo_ffsplit_cluster_state cluster_state;
-	const struct node_list *quorate_partition_node_list;
+	struct node_list quorate_partition_node_list;
 };
 
 enum qnetd_algo_ffsplit_client_state {
@@ -75,21 +76,21 @@ qnetd_algo_ffsplit_client_init(struct qnetd_client *client)
 	if (qnetd_cluster_size(client->cluster) == 1) {
 		cluster_data = malloc(sizeof(*cluster_data));
 		if (cluster_data == NULL) {
-			qnetd_log(LOG_ERR, "ffsplit: Can't initialize cluster data for client %s",
+			log(LOG_ERR, "ffsplit: Can't initialize cluster data for client %s",
 			    client->addr_str);
 
 			return (TLV_REPLY_ERROR_CODE_INTERNAL_ERROR);
 		}
 		memset(cluster_data, 0, sizeof(*cluster_data));
 		cluster_data->cluster_state = QNETD_ALGO_FFSPLIT_CLUSTER_STATE_WAITING_FOR_CHANGE;
-		cluster_data->quorate_partition_node_list = NULL;
+		node_list_init(&cluster_data->quorate_partition_node_list);
 
 		client->cluster->algorithm_data = cluster_data;
 	}
 
 	client_data = malloc(sizeof(*client_data));
 	if (client_data == NULL) {
-		qnetd_log(LOG_ERR, "ffsplit: Can't initialize node data for client %s",
+		log(LOG_ERR, "ffsplit: Can't initialize node data for client %s",
 		    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_INTERNAL_ERROR);
@@ -102,25 +103,25 @@ qnetd_algo_ffsplit_client_init(struct qnetd_client *client)
 }
 
 static int
-qnetd_algo_ffsplit_is_prefered_partition(const struct qnetd_client *client,
+qnetd_algo_ffsplit_is_preferred_partition(const struct qnetd_client *client,
     const struct node_list *config_node_list, const struct node_list *membership_node_list)
 {
-	uint32_t prefered_node_id;
+	uint32_t preferred_node_id;
 	struct node_list_entry *node_entry;
 	int case_processed;
 
-	prefered_node_id = 0;
+	preferred_node_id = 0;
 	case_processed = 0;
 
 	switch (client->tie_breaker.mode) {
 	case TLV_TIE_BREAKER_MODE_LOWEST:
 		node_entry = TAILQ_FIRST(config_node_list);
 
-		prefered_node_id = node_entry->node_id;
+		preferred_node_id = node_entry->node_id;
 
 		TAILQ_FOREACH(node_entry, config_node_list, entries) {
-			if (node_entry->node_id < prefered_node_id) {
-				prefered_node_id = node_entry->node_id;
+			if (node_entry->node_id < preferred_node_id) {
+				preferred_node_id = node_entry->node_id;
 			}
 		}
 		case_processed = 1;
@@ -128,28 +129,28 @@ qnetd_algo_ffsplit_is_prefered_partition(const struct qnetd_client *client,
 	case TLV_TIE_BREAKER_MODE_HIGHEST:
 		node_entry = TAILQ_FIRST(config_node_list);
 
-		prefered_node_id = node_entry->node_id;
+		preferred_node_id = node_entry->node_id;
 
 		TAILQ_FOREACH(node_entry, config_node_list, entries) {
-			if (node_entry->node_id > prefered_node_id) {
-				prefered_node_id = node_entry->node_id;
+			if (node_entry->node_id > preferred_node_id) {
+				preferred_node_id = node_entry->node_id;
 			}
 		}
 		case_processed = 1;
 		break;
 	case TLV_TIE_BREAKER_MODE_NODE_ID:
-		prefered_node_id = client->tie_breaker.node_id;
+		preferred_node_id = client->tie_breaker.node_id;
 		case_processed = 1;
 		break;
 	}
 
 	if (!case_processed) {
-		qnetd_log(LOG_CRIT, "qnetd_algo_ffsplit_is_prefered_partition unprocessed "
+		log(LOG_CRIT, "qnetd_algo_ffsplit_is_preferred_partition unprocessed "
 		    "tie_breaker.mode");
 		exit(1);
 	}
 
-	return (node_list_find_node_id(membership_node_list, prefered_node_id) != NULL);
+	return (node_list_find_node_id(membership_node_list, preferred_node_id) != NULL);
 }
 
 static int
@@ -336,12 +337,18 @@ qnetd_algo_ffsplit_partition_cmp(const struct qnetd_client *client1,
     enum tlv_heuristics heuristics_1,
     const struct qnetd_client *client2,
     const struct node_list *config_node_list2, const struct node_list *membership_node_list2,
-    enum tlv_heuristics heuristics_2)
+    enum tlv_heuristics heuristics_2,
+    const struct node_list *quorate_partition_node_list,
+    int keep_active_partition_tie_breaker)
 {
 	size_t part1_active_clients, part2_active_clients;
 	size_t part1_no_heuristics_pass, part2_no_heuristics_pass;
 	size_t part1_no_heuristics_fail, part2_no_heuristics_fail;
 	size_t part1_score, part2_score;
+	/* Result of node_list_find_node_id of client 1 node id in quorate_partition_node_list */
+	struct node_list_entry *qpnl_client1;
+	/* Result of node_list_find_node_id of client 2 node id in quorate_partition_node_list */
+	struct node_list_entry *qpnl_client2;
 
 	int res;
 
@@ -400,6 +407,9 @@ qnetd_algo_ffsplit_partition_cmp(const struct qnetd_client *client1,
 			res = 0; goto exit_res;
 		}
 
+		/*
+		 * This also handles NULL client (best_client)
+		 */
 		if (part1_active_clients > part2_active_clients) {
 			res = 1; goto exit_res;
 		} else if (part1_active_clients < part2_active_clients) {
@@ -407,10 +417,34 @@ qnetd_algo_ffsplit_partition_cmp(const struct qnetd_client *client1,
 		}
 
 		/*
-		 * Number of active clients in both partitions equals. Use tie-breaker.
+		 * Use keep active partition tie-breaker if enabled for both clients
+		 */
+		if (keep_active_partition_tie_breaker && client2 != NULL) {
+			qpnl_client1 = node_list_find_node_id(quorate_partition_node_list, client1->node_id);
+			qpnl_client2 = node_list_find_node_id(quorate_partition_node_list, client2->node_id);
+
+			/*
+			 * Client 1 in quorate partition, client 2 isn't and vice-versa.
+			 * If both either doesn't exist in quorate partion or both exists use
+			 * next tie-breaker
+			 */
+			if (qpnl_client1 != NULL && qpnl_client2 == NULL) {
+				res = 1; goto exit_res;
+			} else if (qpnl_client1 == NULL && qpnl_client2 != NULL) {
+				res = 0; goto exit_res;
+			}
+		}
+
+		/*
+		 * All previous metrics failed (client1 and client2 are equal).
+		 * Scores (number of clients + heuristics) are equal,
+		 * number of active clients in both partitions equals
+		 * and keep_active_partition_tie_breaker is either disabled or both clients
+		 * either were or weren't members of previous quorate partition.
+		 * Last step is to use tie-breaker.
 		 */
 
-		if (qnetd_algo_ffsplit_is_prefered_partition(client1, config_node_list1,
+		if (qnetd_algo_ffsplit_is_preferred_partition(client1, config_node_list1,
 		    membership_node_list1)) {
 			res = 1; goto exit_res;
 		} else {
@@ -420,7 +454,7 @@ qnetd_algo_ffsplit_partition_cmp(const struct qnetd_client *client1,
 
 exit_res:
 	if (res == -1) {
-		qnetd_log(LOG_CRIT, "qnetd_algo_ffsplit_partition_cmp unhandled case");
+		log(LOG_CRIT, "qnetd_algo_ffsplit_partition_cmp unhandled case");
 		exit(1);
 		/* NOTREACHED */
 	}
@@ -435,18 +469,28 @@ exit_res:
 static const struct node_list *
 qnetd_algo_ffsplit_select_partition(const struct qnetd_client *client, int client_leaving,
     const struct node_list *config_node_list, const struct node_list *membership_node_list,
-    enum tlv_heuristics client_heuristics)
+    const struct node_list *quorate_partition_node_list, enum tlv_heuristics client_heuristics)
 {
 	const struct qnetd_client *iter_client;
 	const struct qnetd_client *best_client;
 	const struct node_list *best_config_node_list, *best_membership_node_list;
 	const struct node_list *iter_config_node_list, *iter_membership_node_list;
 	enum tlv_heuristics iter_heuristics, best_heuristics;
+	int keep_active_partition_tie_breaker;
 
 	best_client = NULL;
 	best_config_node_list = best_membership_node_list = NULL;
 	best_heuristics = TLV_HEURISTICS_UNDEFINED;
 
+	keep_active_partition_tie_breaker = 1;
+
+	TAILQ_FOREACH(iter_client, &client->cluster->client_list, cluster_entries) {
+		if (!iter_client->keep_active_partition_tie_breaker) {
+			keep_active_partition_tie_breaker = 0;
+			break;
+		}
+	}
+
 	/*
 	 * Get highest score
 	 */
@@ -467,7 +511,8 @@ qnetd_algo_ffsplit_select_partition(const struct qnetd_client *client, int clien
 
 		if (qnetd_algo_ffsplit_partition_cmp(iter_client, iter_config_node_list,
 		    iter_membership_node_list, iter_heuristics, best_client, best_config_node_list,
-		    best_membership_node_list, best_heuristics) > 0) {
+		    best_membership_node_list, best_heuristics,
+		    quorate_partition_node_list, keep_active_partition_tie_breaker) > 0) {
 			best_client = iter_client;
 			best_config_node_list = iter_config_node_list;
 			best_membership_node_list = iter_membership_node_list;
@@ -595,10 +640,11 @@ qnetd_algo_ffsplit_no_clients_in_sending_state(struct qnetd_client *client, int
 	return (no_clients);
 }
 
-static enum tlv_vote
+static enum tlv_reply_error_code
 qnetd_algo_ffsplit_do(struct qnetd_client *client, int client_leaving,
     const struct tlv_ring_id *ring_id, const struct node_list *config_node_list,
-    const struct node_list *membership_node_list, enum tlv_heuristics client_heuristics)
+    const struct node_list *membership_node_list, enum tlv_heuristics client_heuristics,
+    enum tlv_vote *result_vote)
 {
 	struct qnetd_algo_ffsplit_cluster_data *cluster_data;
 	const struct node_list *quorate_partition_node_list;
@@ -612,22 +658,32 @@ qnetd_algo_ffsplit_do(struct qnetd_client *client, int client_leaving,
 		/*
 		 * Wait until membership is stable
 		 */
-		qnetd_log(LOG_DEBUG, "ffsplit: Membership for cluster %s is not yet stable", client->cluster_name);
+		log(LOG_DEBUG, "ffsplit: Membership for cluster %s is not yet stable", client->cluster_name);
+		*result_vote = TLV_VOTE_WAIT_FOR_REPLY;
 
-		return (TLV_VOTE_WAIT_FOR_REPLY);
+		return (TLV_REPLY_ERROR_CODE_NO_ERROR);
 	}
 
-	qnetd_log(LOG_DEBUG, "ffsplit: Membership for cluster %s is now stable", client->cluster_name);
+	log(LOG_DEBUG, "ffsplit: Membership for cluster %s is now stable", client->cluster_name);
 
 	quorate_partition_node_list = qnetd_algo_ffsplit_select_partition(client, client_leaving,
-	    config_node_list, membership_node_list, client_heuristics);
-	cluster_data->quorate_partition_node_list = quorate_partition_node_list;
+	    config_node_list, membership_node_list, &cluster_data->quorate_partition_node_list,
+	    client_heuristics);
+
+	node_list_free(&cluster_data->quorate_partition_node_list);
 
 	if (quorate_partition_node_list == NULL) {
-		qnetd_log(LOG_DEBUG, "ffsplit: No quorate partition was selected");
+		log(LOG_DEBUG, "ffsplit: No quorate partition was selected");
 	} else {
-		qnetd_log(LOG_DEBUG, "ffsplit: Quorate partition selected");
-		qnetd_log_debug_dump_node_list(client, quorate_partition_node_list);
+		log(LOG_DEBUG, "ffsplit: Quorate partition selected");
+		log_common_debug_dump_node_list(quorate_partition_node_list);
+
+		if (node_list_clone(&cluster_data->quorate_partition_node_list,
+		    quorate_partition_node_list) != 0) {
+			log(LOG_ERR, "ffsplit: Can't clone quourate partition node list");
+
+			return (TLV_REPLY_ERROR_CODE_INTERNAL_ERROR);
+		}
 	}
 
 	qnetd_algo_ffsplit_update_nodes_state(client, client_leaving, quorate_partition_node_list);
@@ -635,14 +691,14 @@ qnetd_algo_ffsplit_do(struct qnetd_client *client, int client_leaving,
 	cluster_data->cluster_state = QNETD_ALGO_FFSPLIT_CLUSTER_STATE_SENDING_NACKS;
 
 	if (qnetd_algo_ffsplit_send_votes(client, client_leaving, ring_id, 0) == 0) {
-		qnetd_log(LOG_DEBUG, "ffsplit: No client gets NACK");
+		log(LOG_DEBUG, "ffsplit: No client gets NACK");
 		/*
 		 * No one gets nack -> send acks
 		 */
 		cluster_data->cluster_state = QNETD_ALGO_FFSPLIT_CLUSTER_STATE_SENDING_ACKS;
 
 		if (qnetd_algo_ffsplit_send_votes(client, client_leaving, ring_id, 1) == 0) {
-			qnetd_log(LOG_DEBUG, "ffsplit: No client gets ACK");
+			log(LOG_DEBUG, "ffsplit: No client gets ACK");
 			/*
 			 * No one gets acks -> finished
 			 */
@@ -650,7 +706,9 @@ qnetd_algo_ffsplit_do(struct qnetd_client *client, int client_leaving,
 		}
 	}
 
-	return (TLV_VOTE_NO_CHANGE);
+	*result_vote = TLV_VOTE_NO_CHANGE;
+
+	return (TLV_REPLY_ERROR_CODE_NO_ERROR);
 }
 
 enum tlv_reply_error_code
@@ -658,12 +716,15 @@ qnetd_algo_ffsplit_config_node_list_received(struct qnetd_client *client,
     uint32_t msg_seq_num, int config_version_set, uint64_t config_version,
     const struct node_list *nodes, int initial, enum tlv_vote *result_vote)
 {
+	enum tlv_reply_error_code reply_error_code;
+
+	reply_error_code = TLV_REPLY_ERROR_CODE_NO_ERROR;
 
 	if (node_list_size(nodes) == 0) {
 		/*
 		 * Empty node list shouldn't happen
 		 */
-		qnetd_log(LOG_ERR, "ffsplit: Received empty config node list for client %s",
+		log(LOG_ERR, "ffsplit: Received empty config node list for client %s",
 			    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_INVALID_CONFIG_NODE_LIST);
@@ -673,7 +734,7 @@ qnetd_algo_ffsplit_config_node_list_received(struct qnetd_client *client,
 		/*
 		 * Current node is not in node list
 		 */
-		qnetd_log(LOG_ERR, "ffsplit: Received config node list without client %s",
+		log(LOG_ERR, "ffsplit: Received config node list without client %s",
 			    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_INVALID_CONFIG_NODE_LIST);
@@ -685,11 +746,12 @@ qnetd_algo_ffsplit_config_node_list_received(struct qnetd_client *client,
 		 */
 		*result_vote = TLV_VOTE_ASK_LATER;
 	} else {
-		*result_vote = qnetd_algo_ffsplit_do(client, 0, &client->last_ring_id,
-		    nodes, &client->last_membership_node_list, client->last_heuristics);
+		reply_error_code = qnetd_algo_ffsplit_do(client, 0, &client->last_ring_id,
+		    nodes, &client->last_membership_node_list, client->last_heuristics,
+		    result_vote);
 	}
 
-	return (TLV_REPLY_ERROR_CODE_NO_ERROR);
+	return (reply_error_code);
 }
 
 /*
@@ -711,12 +773,15 @@ qnetd_algo_ffsplit_membership_node_list_received(struct qnetd_client *client,
     uint32_t msg_seq_num, const struct tlv_ring_id *ring_id,
     const struct node_list *nodes, enum tlv_heuristics heuristics, enum tlv_vote *result_vote)
 {
+	enum tlv_reply_error_code reply_error_code;
+
+	reply_error_code = TLV_REPLY_ERROR_CODE_NO_ERROR;
 
 	if (node_list_size(nodes) == 0) {
 		/*
 		 * Empty node list shouldn't happen
 		 */
-		qnetd_log(LOG_ERR, "ffsplit: Received empty membership node list for client %s",
+		log(LOG_ERR, "ffsplit: Received empty membership node list for client %s",
 			    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_INVALID_MEMBERSHIP_NODE_LIST);
@@ -726,7 +791,7 @@ qnetd_algo_ffsplit_membership_node_list_received(struct qnetd_client *client,
 		/*
 		 * Current node is not in node list
 		 */
-		qnetd_log(LOG_ERR, "ffsplit: Received membership node list without client %s",
+		log(LOG_ERR, "ffsplit: Received membership node list without client %s",
 			    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_INVALID_MEMBERSHIP_NODE_LIST);
@@ -738,11 +803,12 @@ qnetd_algo_ffsplit_membership_node_list_received(struct qnetd_client *client,
 		 */
 		*result_vote = TLV_VOTE_ASK_LATER;
 	} else {
-		*result_vote = qnetd_algo_ffsplit_do(client, 0, ring_id,
-		    &client->configuration_node_list, nodes, heuristics);
+		reply_error_code = qnetd_algo_ffsplit_do(client, 0, ring_id,
+		    &client->configuration_node_list, nodes, heuristics,
+		    result_vote);
 	}
 
-	return (TLV_REPLY_ERROR_CODE_NO_ERROR);
+	return (reply_error_code);
 }
 
 enum tlv_reply_error_code
@@ -762,10 +828,16 @@ qnetd_algo_ffsplit_quorum_node_list_received(struct qnetd_client *client,
 void
 qnetd_algo_ffsplit_client_disconnect(struct qnetd_client *client, int server_going_down)
 {
+	enum tlv_vote result_vote;
+	struct qnetd_algo_ffsplit_cluster_data *cluster_data;
 
-	(void)qnetd_algo_ffsplit_do(client, 1, &client->last_ring_id,
-	    &client->configuration_node_list, &client->last_membership_node_list,
-	    client->last_heuristics);
+	cluster_data = (struct qnetd_algo_ffsplit_cluster_data *)client->cluster->algorithm_data;
+
+	if (!server_going_down) {
+		(void)qnetd_algo_ffsplit_do(client, 1, &client->last_ring_id,
+		    &client->configuration_node_list, &client->last_membership_node_list,
+		    client->last_heuristics, &result_vote);
+	}
 
 	free(client->algorithm_data);
 
@@ -773,7 +845,9 @@ qnetd_algo_ffsplit_client_disconnect(struct qnetd_client *client, int server_goi
 		/*
 		 * Last client in the cluster
 		 */
-		 free(client->cluster->algorithm_data);
+		node_list_free(&cluster_data->quorate_partition_node_list);
+
+		free(client->cluster->algorithm_data);
 	}
 }
 
@@ -798,7 +872,7 @@ qnetd_algo_ffsplit_vote_info_reply_received(struct qnetd_client *client, uint32_
 	client_data = (struct qnetd_algo_ffsplit_client_data *)client->algorithm_data;
 
 	if (client_data->vote_info_expected_seq_num != msg_seq_num) {
-		qnetd_log(LOG_DEBUG, "ffsplit: Received old vote info reply from client %s",
+		log(LOG_DEBUG, "ffsplit: Received old vote info reply from client %s",
 		    client->addr_str);
 
 		return (TLV_REPLY_ERROR_CODE_NO_ERROR);
@@ -813,13 +887,13 @@ qnetd_algo_ffsplit_vote_info_reply_received(struct qnetd_client *client, uint32_
 
 	if (cluster_data->cluster_state == QNETD_ALGO_FFSPLIT_CLUSTER_STATE_SENDING_NACKS) {
 		if (qnetd_algo_ffsplit_no_clients_in_sending_state(client, 0) == 0) {
-			qnetd_log(LOG_DEBUG, "ffsplit: All NACK votes sent for cluster %s",
+			log(LOG_DEBUG, "ffsplit: All NACK votes sent for cluster %s",
 			     client->cluster_name);
 
 			cluster_data->cluster_state = QNETD_ALGO_FFSPLIT_CLUSTER_STATE_SENDING_ACKS;
 
 			if (qnetd_algo_ffsplit_send_votes(client, 0, &client->last_ring_id, 1) == 0) {
-				qnetd_log(LOG_DEBUG, "ffsplit: No client gets ACK");
+				log(LOG_DEBUG, "ffsplit: No client gets ACK");
 				/*
 				 * No one gets acks -> finished
 				 */
@@ -828,7 +902,7 @@ qnetd_algo_ffsplit_vote_info_reply_received(struct qnetd_client *client, uint32_
 		}
 	} else {
 		if (qnetd_algo_ffsplit_no_clients_in_sending_state(client, 1) == 0) {
-			qnetd_log(LOG_DEBUG, "ffsplit: All ACK votes sent for cluster %s",
+			log(LOG_DEBUG, "ffsplit: All ACK votes sent for cluster %s",
 			     client->cluster_name);
 
 			cluster_data->cluster_state = QNETD_ALGO_FFSPLIT_CLUSTER_STATE_WAITING_FOR_CHANGE;
@@ -842,6 +916,9 @@ enum tlv_reply_error_code
 qnetd_algo_ffsplit_heuristics_change_received(struct qnetd_client *client, uint32_t msg_seq_num,
     enum tlv_heuristics heuristics, enum tlv_vote *result_vote)
 {
+	enum tlv_reply_error_code reply_error_code;
+
+	reply_error_code = TLV_REPLY_ERROR_CODE_NO_ERROR;
 
 	if (node_list_size(&client->configuration_node_list) == 0 ||
 	    node_list_size(&client->last_membership_node_list) == 0) {
@@ -850,12 +927,12 @@ qnetd_algo_ffsplit_heuristics_change_received(struct qnetd_client *client, uint3
 		 */
 		*result_vote = TLV_VOTE_ASK_LATER;
 	} else {
-		*result_vote = qnetd_algo_ffsplit_do(client, 0, &client->last_ring_id,
+		reply_error_code = qnetd_algo_ffsplit_do(client, 0, &client->last_ring_id,
 		    &client->configuration_node_list, &client->last_membership_node_list,
-		    heuristics);
+		    heuristics, result_vote);
 	}
 
-	return (TLV_REPLY_ERROR_CODE_NO_ERROR);
+	return (reply_error_code);
 }
 
 enum tlv_reply_error_code
