@@ -46,10 +46,12 @@
 #include <sys/un.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <limits.h>
 
 #include <corosync/corotypes.h>
 #include <corosync/totem/totem.h>
 #include <corosync/cfg.h>
+#include "util.h"
 
 #define cs_repeat(result, max, code)				\
 	do {							\
@@ -74,18 +76,18 @@ static int ringstatusget_do (char *interface_name)
 	char **interface_status;
 	unsigned int i;
 	unsigned int nodeid;
-	int rc = 0;
+	int rc = EXIT_SUCCESS;
 
 	printf ("Printing ring status.\n");
 	result = corosync_cfg_initialize (&handle, NULL);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %d\n", result);
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %d\n", result);
+		exit (EXIT_FAILURE);
 	}
 
 	result = corosync_cfg_local_get(handle, &nodeid);
 	if (result != CS_OK) {
-		printf ("Could not get the local node id, the error is: %d\n", result);
+		fprintf (stderr, "Could not get the local node id, the error is: %d\n", result);
 	}
 	else {
 		printf ("Local node ID %u\n", nodeid);
@@ -96,7 +98,7 @@ static int ringstatusget_do (char *interface_name)
 				&interface_status,
 				&interface_count);
 	if (result != CS_OK) {
-		printf ("Could not get the ring status, the error is: %d\n", result);
+		fprintf (stderr, "Could not get the ring status, the error is: %d\n", result);
 	} else {
 		for (i = 0; i < interface_count; i++) {
 			if ( (interface_name && 
@@ -108,7 +110,7 @@ static int ringstatusget_do (char *interface_name)
 				printf ("\tid\t= %s\n", interface_names[i]);
 				printf ("\tstatus\t= %s\n", interface_status[i]);
 				if (strstr(interface_status[i], "FAULTY")) {
-					rc = 1;
+					rc = EXIT_FAILURE;
 				}
 			}
 		}
@@ -133,13 +135,13 @@ static void ringreenable_do (void)
 	printf ("Re-enabling all failed rings.\n");
 	result = corosync_cfg_initialize (&handle, NULL);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %d\n", result);
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %d\n", result);
+		exit (EXIT_FAILURE);
 	}
 
 	result = corosync_cfg_ring_reenable (handle);
 	if (result != CS_OK) {
-		printf ("Could not re-enable ring error %d\n", result);
+		fprintf (stderr, "Could not re-enable ring error %d\n", result);
 	}
 
 	(void)corosync_cfg_finalize (handle);
@@ -151,18 +153,18 @@ static int reload_config_do (void)
 	corosync_cfg_handle_t handle;
 	int rc;
 
-	rc = 0;
+	rc = EXIT_SUCCESS;
 
 	printf ("Reloading corosync.conf...\n");
 	result = corosync_cfg_initialize (&handle, NULL);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %s\n", cs_strerror(result));
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %s\n", cs_strerror(result));
+		exit (EXIT_FAILURE);
 	}
 
 	result = corosync_cfg_reload_config (handle);
 	if (result != CS_OK) {
-		printf ("Could not reload configuration. Error %s\n", cs_strerror(result));
+		fprintf (stderr, "Could not reload configuration. Error %s\n", cs_strerror(result));
 		rc = (int)result;
 	}
 	else {
@@ -184,14 +186,14 @@ static void shutdown_do(void)
 
 	result = corosync_cfg_initialize (&handle, &callbacks);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %d\n", result);
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %d\n", result);
+		exit (EXIT_FAILURE);
 	}
 
 	printf ("Shutting down corosync\n");
 	cs_repeat(result, 30, corosync_cfg_try_shutdown (handle, COROSYNC_CFG_SHUTDOWN_FLAG_REQUEST));
 	if (result != CS_OK) {
-		printf ("Could not shutdown (error = %d)\n", result);
+		fprintf (stderr, "Could not shutdown (error = %d)\n", result);
 	}
 
 	(void)corosync_cfg_finalize (handle);
@@ -201,16 +203,15 @@ static void showaddrs_do(unsigned int nodeid)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
-	corosync_cfg_callbacks_t callbacks;
 	int numaddrs;
 	int i;
 	corosync_cfg_node_address_t addrs[INTERFACE_MAX];
 
 
-	result = corosync_cfg_initialize (&handle, &callbacks);
+	result = corosync_cfg_initialize (&handle, NULL);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %d\n", result);
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %d\n", result);
+		exit (EXIT_FAILURE);
 	}
 
 	if (corosync_cfg_get_node_addrs(handle, nodeid, INTERFACE_MAX, &numaddrs, addrs) == CS_OK) {
@@ -248,12 +249,12 @@ static void killnode_do(unsigned int nodeid)
 	printf ("Killing node %d\n", nodeid);
 	result = corosync_cfg_initialize (&handle, NULL);
 	if (result != CS_OK) {
-		printf ("Could not initialize corosync configuration API error %d\n", result);
-		exit (1);
+		fprintf (stderr, "Could not initialize corosync configuration API error %d\n", result);
+		exit (EXIT_FAILURE);
 	}
 	result = corosync_cfg_kill_node (handle, nodeid, "Killed by corosync-cfgtool");
 	if (result != CS_OK) {
-		printf ("Could not kill node (error = %d)\n", result);
+		fprintf (stderr, "Could not kill node (error = %d)\n", result);
 	}
 	(void)corosync_cfg_finalize (handle);
 }
@@ -280,7 +281,8 @@ int main (int argc, char *argv[]) {
 	int opt;
 	unsigned int nodeid;
 	char interface_name[128] = "";
-	int rc=0;
+	int rc = EXIT_SUCCESS;
+	long long int l;
 
 	if (argc == 1) {
 		usage_do ();
@@ -301,14 +303,22 @@ int main (int argc, char *argv[]) {
 			ringreenable_do ();
 			break;
 		case 'k':
-			nodeid = atoi (optarg);
+			if (util_strtonum(optarg, 1, UINT_MAX, &l) == -1) {
+				fprintf(stderr, "The nodeid was not valid, try a positive number\n");
+				exit(EXIT_FAILURE);
+			}
+			nodeid = l;
 			killnode_do(nodeid);
 			break;
 		case 'H':
 			shutdown_do();
 			break;
 		case 'a':
-			nodeid = atoi (optarg);
+			if (util_strtonum(optarg, 1, UINT_MAX, &l) == -1) {
+				fprintf(stderr, "The nodeid was not valid, try a positive number\n");
+				exit(EXIT_FAILURE);
+			}
+			nodeid = l;
 			showaddrs_do(nodeid);
 			break;
 		case 'h':
