@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2014 Red Hat, Inc.
+ * Copyright (c) 2009-2020 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -48,6 +48,7 @@
 #include <corosync/cmap.h>
 #include <corosync/quorum.h>
 #include <corosync/votequorum.h>
+#include "util.h"
 
 typedef enum {
 	NODEID_FORMAT_DECIMAL,
@@ -60,7 +61,6 @@ typedef enum {
 } name_format_t;
 
 typedef enum {
-	CMD_UNKNOWN,
 	CMD_SHOWNODES,
 	CMD_SHOWSTATUS,
 	CMD_SETVOTES,
@@ -75,6 +75,8 @@ typedef enum {
 	SORT_NODENAME
 } sorttype_t;
 
+#define EXIT_NOT_QUORATE	2
+
 /*
  * global vars
  */
@@ -238,7 +240,7 @@ static int set_votes(uint32_t nodeid, int votes)
 			votes, nodeid, cs_strerror(err));
 	}
 
-	return err==CS_OK?0:err;
+	return (err == CS_OK ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
 static int set_expected(int expected_votes)
@@ -249,7 +251,7 @@ static int set_expected(int expected_votes)
 		fprintf(stderr, "Unable to set expected votes: %s\n", cs_strerror(err));
 	}
 
-	return err==CS_OK?0:err;
+	return (err == CS_OK ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
 /*
@@ -259,8 +261,8 @@ static int set_expected(int expected_votes)
 static const char *node_name_by_nodelist(uint32_t nodeid)
 {
 	cmap_iter_handle_t iter;
-	char key_name[CMAP_KEYNAME_MAXLEN];
-	char tmp_key[CMAP_KEYNAME_MAXLEN];
+	char key_name[CMAP_KEYNAME_MAXLEN + 1];
+	char tmp_key[CMAP_KEYNAME_MAXLEN + 1];
 	static char ret_buf[_POSIX_HOST_NAME_MAX];
 	char *str = NULL;
 	uint32_t node_pos, cur_nodeid;
@@ -332,6 +334,7 @@ static const char *node_name(uint32_t nodeid, name_format_t name_format)
 	if ((nodelist_name) &&
 	    (strlen(nodelist_name) > 0)) {
 		start_addr = 1;
+		assert(strlen(nodelist_name) < sizeof(buf));
 		strcpy(buf, nodelist_name);
 		bufptr = strlen(buf);
 	}
@@ -638,9 +641,9 @@ static int display_quorum_data(int is_quorate,
 }
 
 /*
- * return  1 if quorate
- *         0 if not quorate
- *        -1 on error
+ * return EXIT_SUCCESS if quorate
+ *        EXIT_NOT_QUORATE if not quorate
+ *        EXIT_FAILURE on error
  */
 static int show_status(nodeid_format_t nodeid_format, name_format_t name_format, sorttype_t sort_type)
 {
@@ -689,15 +692,15 @@ static int show_status(nodeid_format_t nodeid_format, name_format_t name_format,
 
 quorum_err:
 	if (err != CS_OK) {
-		return -1;
+		return EXIT_FAILURE;
 	}
 
 	err = display_quorum_data(is_quorate, nodeid_format, name_format, sort_type, 0);
 	if (err != CS_OK) {
-		return -1;
+		return EXIT_FAILURE;
 	}
 
-	return is_quorate;
+	return (is_quorate ? EXIT_SUCCESS : EXIT_NOT_QUORATE);
 }
 
 static int monitor_status(nodeid_format_t nodeid_format, name_format_t name_format, sorttype_t sort_type) {
@@ -750,7 +753,7 @@ static int monitor_status(nodeid_format_t nodeid_format, name_format_t name_form
 	}
 
 quorum_err:
-	return -1;
+	return EXIT_FAILURE;
 }
 
 static int show_nodes(nodeid_format_t nodeid_format, name_format_t name_format, sorttype_t sort_type)
@@ -784,23 +787,30 @@ static int unregister_qdevice(void)
 {
 	int err;
 	struct votequorum_info info;
+	int result;
+
+	result = EXIT_FAILURE;
 
 	err = votequorum_getinfo(v_handle, our_nodeid, &info);
 	if (err != CS_OK) {
 		fprintf(stderr, "Unable to get quorum device info: %s\n", cs_strerror(err));
-		return -1;
+		goto err_exit;
 	}
 
 	if (!(info.flags & VOTEQUORUM_INFO_QDEVICE_REGISTERED)) {
-		return 0;
+		result = EXIT_SUCCESS;
+		goto err_exit;
 	}
 
 	err = votequorum_qdevice_unregister(v_handle, info.qdevice_name);
 	if (err != CS_OK) {
 		fprintf(stderr, "Unable to unregister quorum device: %s\n", cs_strerror(err));
-		return -1;
+		goto err_exit;
 	}
-	return 0;
+
+	result = EXIT_SUCCESS;
+err_exit:
+	return result;
 }
 
 /*
@@ -869,7 +879,6 @@ static void close_all(void) {
 
 int main (int argc, char *argv[]) {
 	const char *options = "VHaslpmfe:v:hin:o:";
-	char *endptr;
 	int opt;
 	int votes = 0;
 	int ret = 0;
@@ -879,23 +888,12 @@ int main (int argc, char *argv[]) {
 	name_format_t address_format = ADDRESS_FORMAT_NAME;
 	command_t command_opt = CMD_SHOWSTATUS;
 	sorttype_t sort_opt = SORT_ADDR;
-	char sortchar;
-	long int l;
-
-	if (init_all()) {
-		close_all();
-		exit(1);
-	}
+	long long int l;
 
 	while ( (opt = getopt(argc, argv, options)) != -1 ) {
 		switch (opt) {
 		case 'f':
-			if (using_votequorum() > 0) {
-				command_opt = CMD_UNREGISTER_QDEVICE;
-			} else {
-				fprintf(stderr, "You cannot unregister quorum device, corosync is not using votequorum\n");
-				exit(2);
-			}
+			command_opt = CMD_UNREGISTER_QDEVICE;
 			break;
 		case 's':
 			command_opt = CMD_SHOWSTATUS;
@@ -919,74 +917,64 @@ int main (int argc, char *argv[]) {
 			machine_parsable = 1;
 			break;
 		case 'e':
-			if (using_votequorum() > 0) {
-				votes = strtol(optarg, &endptr, 0);
-				if ((votes == 0 && endptr == optarg) || votes <= 0) {
-					fprintf(stderr, "New expected votes value was not valid, try a positive number\n");
-				} else {
-					command_opt = CMD_SETEXPECTED;
-				}
-			} else {
-				fprintf(stderr, "You cannot change expected votes, corosync is not using votequorum\n");
-				exit(2);
+			if (util_strtonum(optarg, 1, INT_MAX, &l) == -1) {
+				fprintf(stderr, "New expected votes value was not valid, try a positive number\n");
+				exit(EXIT_FAILURE);
 			}
+			votes = l;
+			command_opt = CMD_SETEXPECTED;
 			break;
 		case 'n':
-			l = strtol(optarg, &endptr, 0);
-			if ((l == 0 && endptr == optarg) || l < 0) {
+			if (util_strtonum(optarg, 1, UINT_MAX, &l) == -1) {
 				fprintf(stderr, "The nodeid was not valid, try a positive number\n");
-				exit(2);
+				exit(EXIT_FAILURE);
 			}
 			nodeid = l;
 			nodeid_set = 1;
 			break;
 		case 'v':
-			if (using_votequorum() > 0) {
-				votes = strtol(optarg, &endptr, 0);
-				if ((votes == 0 && endptr == optarg) || votes < 0) {
-					fprintf(stderr, "New votes value was not valid, try a positive number or zero\n");
-					exit(2);
-				} else {
-					command_opt = CMD_SETVOTES;
-				}
-			}
-			else {
-				fprintf(stderr, "You cannot change node votes, corosync is not using votequorum\n");
-				exit(2);
+			if (util_strtonum(optarg, 0, INT_MAX, &l) == -1) {
+				fprintf(stderr, "New votes value was not valid, try a positive number or zero\n");
+				exit(EXIT_FAILURE);
 			}
+			votes = l;
+			command_opt = CMD_SETVOTES;
 			break;
 		case 'o':
-			sortchar = optarg[0];
-			switch (sortchar) {
-			        case 'a': sort_opt = SORT_ADDR;
-					break;
-			        case 'i': sort_opt = SORT_NODEID;
-					break;
-			        case 'n': sort_opt = SORT_NODENAME;
-					break;
-			        default:
-					fprintf(stderr, "Invalid ordering option. valid orders are a(address), i(node ID) or n(name)\n");
-					exit(2);
-					break;
+			if (strcmp(optarg, "a") == 0) {
+				sort_opt = SORT_ADDR;
+			} else if (strcmp(optarg, "i") == 0) {
+				sort_opt = SORT_NODEID;
+			} else if (strcmp(optarg, "n") == 0) {
+				sort_opt = SORT_NODENAME;
+			} else {
+				fprintf(stderr, "Invalid ordering option. valid orders are a(address), i(node ID) or n(name)\n");
+				exit(EXIT_FAILURE);
 			}
 			break;
 		case 'V':
 			printf("corosync-quorumtool version: %s\n", VERSION);
-			exit(0);
-		case ':':
+			exit(EXIT_SUCCESS);
+			break;
 		case 'h':
+			show_usage(argv[0]);
+			exit(EXIT_SUCCESS);
+			break;
+		case ':':
 		case '?':
 		default:
-			command_opt = CMD_UNKNOWN;
+			show_usage(argv[0]);
+			exit(EXIT_FAILURE);
 			break;
 		}
 	}
 
+	if (init_all()) {
+		close_all();
+		exit(EXIT_FAILURE);
+	}
+
 	switch (command_opt) {
-	case CMD_UNKNOWN:
-		show_usage(argv[0]);
-		ret = -1;
-		break;
 	case CMD_SHOWNODES:
 		ret = show_nodes(nodeid_format, address_format, sort_opt);
 		break;
@@ -994,19 +982,34 @@ int main (int argc, char *argv[]) {
 		ret = show_status(nodeid_format, address_format, sort_opt);
 		break;
 	case CMD_SETVOTES:
-		if (!nodeid_set) {
-			nodeid = our_nodeid;
+		if (using_votequorum() > 0) {
+			if (!nodeid_set) {
+				nodeid = our_nodeid;
+			}
+			ret = set_votes(nodeid, votes);
+		} else {
+			fprintf(stderr, "You cannot change node votes, corosync is not using votequorum\n");
+			ret = EXIT_FAILURE;
 		}
-		ret = set_votes(nodeid, votes);
 		break;
 	case CMD_SETEXPECTED:
-		ret = set_expected(votes);
+		if (using_votequorum() > 0) {
+			ret = set_expected(votes);
+		} else {
+			fprintf(stderr, "You cannot change expected votes, corosync is not using votequorum\n");
+			ret = EXIT_FAILURE;
+		}
 		break;
 	case CMD_MONITOR:
 		ret = monitor_status(nodeid_format, address_format, sort_opt);
 		break;
 	case CMD_UNREGISTER_QDEVICE:
-		ret = unregister_qdevice();
+		if (using_votequorum() > 0) {
+			ret = unregister_qdevice();
+		} else {
+			fprintf(stderr, "You cannot unregister quorum device, corosync is not using votequorum\n");
+			ret = EXIT_FAILURE;
+		}
 		break;
 	}
 
